@@ -11,7 +11,7 @@ __email__ = 'matt@joyce.nyc'
 __copyright__ = 'Copyright 2016, Symphony Communication Services LLC'
 
 
-import os
+import pkg_resources
 
 from bravado.requests_client import RequestsClient
 from bravado.client import SwaggerClient
@@ -21,9 +21,8 @@ from bravado.swagger_model import load_file
 class SymCodegen():
 
     def __init__(self):
-        mydir = os.path.dirname(os.path.abspath(__file__))
-        self.config_path = os.path.join(mydir, '../config/')
-        self.rando = 'wat'
+        self.agent_swagger = pkg_resources.resource_filename('symphonybinding', 'data/agent-api-public-deprecated.yaml')
+        self.pod_swagger = pkg_resources.resource_filename('symphonybinding', 'data/pod-api-public-deprecated.yaml')
 
     def agent_cg(self, url):
         http_client = RequestsClient()
@@ -31,7 +30,7 @@ class SymCodegen():
         assert http_client
         # load deprecated agent codegen objects from spec
         try:
-            agent = SwaggerClient.from_spec(load_file(self.config_path + 'agent-api-public-deprecated.yaml'),
+            agent = SwaggerClient.from_spec(load_file(self.agent_swagger),
                                             config={'also_return_response': True})
             agent.swagger_spec.api_url = self.__url__
         except Exception as err:
@@ -44,7 +43,7 @@ class SymCodegen():
         assert http_client
         # load deprecated agent codegen objects from spec
         try:
-            pod = SwaggerClient.from_spec(load_file(self.config_path + '/pod-api-public-deprecated.yaml'),
+            pod = SwaggerClient.from_spec(load_file(self.pod_swagger),
                                           config={'also_return_response': True})
             pod.swagger_spec.api_url = self.__url__
         except Exception as err:
